@@ -5,7 +5,7 @@ import shutil
 import PySimpleGUI as sg
 import sys
 import os
-from Excelutilities.importing_data_helpers import is_col_block_bool
+from Excelutilities import importing_data_helpers 
 from Excelutilities import index_helpers
 import pkg_resources
 first_and_last_row_index = index_helpers.first_and_last_row_index
@@ -181,7 +181,7 @@ def generate_sku(allowed_data_types = [str]):
         for address_and_name in addresses_and_names:
             address = address_and_name[0]
             name = address_and_name[1]
-            if not is_col_block_bool(address):
+            if not importing_data_helpers.is_col_block_bool(address):
                 print(address)
                 sg.popup(f"Oops! Your {name} data wasn't from a single column")
                 sys.exit()
